@@ -1597,6 +1597,29 @@ AccountNumberCheck::Result method_D8(const int *account, int *weight) {
     return AccountNumberCheck::ERROR;
 }
 
+// new method D9 valid from June 4th, 2012, checked with Bundesbank-Testnumbers
+AccountNumberCheck::Result method_D9(const int *account, int *weight) {
+    if (AccountNumberCheck::OK == method_00(account,weight) )	// variant 1
+	return AccountNumberCheck::OK;
+    if (AccountNumberCheck::OK == method_10(account,weight) )	// variant 2
+	return AccountNumberCheck::OK;
+    return method_18(account,weight);	// variant 3
+}
+
+// new method E0 valid from June 3rd, 2013, checked with Bundesbank-Testnumbers
+// note similarities to method_C1/Variant2 and method_17
+AccountNumberCheck::Result method_E0(const int *account, int *weight) {
+    number2Array("2121212120", weight);
+    int tmp = algo03a(weight, true, account, 0, 9);
+    tmp = (tmp + 7) % 10;
+    tmp = 10 - tmp;
+    if (10 == tmp)
+        tmp = 0;
+    if  (tmp == account[9])
+	return AccountNumberCheck::OK;
+    return AccountNumberCheck::ERROR;
+}
+
 struct method_func_s {
     const char *str;
     AccountNumberCheck::MethodFunc func;
@@ -1737,6 +1760,8 @@ const struct method_func_s cb_funcs[] = {
   { "D6", method_D6},
   { "D7", method_D7},
   { "D8", method_D8},
+  { "D9", method_D9},
+  { "E0", method_E0},
   { 0, 0} // Important: The array has to end with the {0,0} entry,
 	  // otherwise initMethodMap() will runaway and crash!
 };
